/* mnote-fuji-data.c
 *
 * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details. 
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "config.h"
#include "mnote-fuji-data.h"

#include <stdlib.h>
#include <string.h>

#include <libexif/exif-byte-order.h>
#include <libexif/exif-utils.h>

struct _MNoteFujiDataPrivate {
	ExifByteOrder order;
};

static void
mnote_fuji_data_free (MNoteData *n)
{
	MNoteFujiData *note = (MNoteFujiData *) n;
	unsigned int i;

	if (note->entries) {
		for (i = 0; i < note->count; i++)
			mnote_fuji_entry_unref (note->entries[i]);
		free (note->entries);
		note->entries = NULL;
		note->count = 0;
	}
}

static char *
mnote_fuji_data_get_value (MNoteData *n, MNoteTag t)
{
	MNoteFujiData *note = (MNoteFujiData *) n;

	note = NULL;

	return (NULL);
}

static void
mnote_fuji_data_save_data (MNoteData *n, unsigned char **data,
			   unsigned int *size)
{
	MNoteFujiData *note = (MNoteFujiData *) n;
	ExifByteOrder order = mnote_data_get_byte_order (n);

	/*
	 * Header: "FUJIFILM" and 4 bytes offset to the first entry.
	 * As the first entry will start right thereafter, the offset is
	 * 0x000c.
	 */
	*data = malloc (12);
	if (!*data)
		return;
	*size = 12;
	memcpy (*data, "FUJIFILM", 8);
	exif_set_long (*data + 8, order, 0x000c);

	note = NULL;
}

static void
mnote_fuji_data_load_data (MNoteData *n, const unsigned char *data,
			   unsigned int size)
{
	MNoteFujiData *note = (MNoteFujiData *) n;

	note = NULL;
}

MNoteData *
mnote_fuji_data_new (void)
{
	MNoteFujiData *note;

	note = malloc (sizeof (MNoteFujiData));
	if (!note)
		return (NULL);
	mnote_data_construct ((MNoteData *) note);
	((MNoteData *) note)->methods.free = mnote_fuji_data_free;
	((MNoteData *) note)->methods.load_data = mnote_fuji_data_load_data;
	((MNoteData *) note)->methods.save_data = mnote_fuji_data_save_data;
	((MNoteData *) note)->methods.get_tag_name = mnote_fuji_tag_get_name;
	((MNoteData *) note)->methods.get_value = mnote_fuji_data_get_value;

	return ((MNoteData *) note);
}
