/* mnote-fuji-tag.c
 *
 * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details. 
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "config.h"
#include "i18n.h"
#include "mnote-fuji-tag.h"

#include <stdlib.h>

static struct {
	MNoteFujiTag tag;
	const char *name;
	const char *title;
	const char *description;
} table[] = {
	{MNOTE_FUJI_TAG_VERSION, "Version", N_("Version"), ""},
	{MNOTE_FUJI_TAG_QUALITY, "Quality", N_("Quality"), ""},
	{MNOTE_FUJI_TAG_SHARPNESS, "Sharpness", N_("Sharpness"), ""},
	{MNOTE_FUJI_TAG_WHITE_BALANCE, "WhiteBalance", N_("White balance"), ""},
	{MNOTE_FUJI_TAG_COLOR, "ChromaticitySaturation", N_("Chromaticity saturation"), ""},
	{MNOTE_FUJI_TAG_TONE, "Contrast", N_("Contrast"), ""},
	{MNOTE_FUJI_TAG_FLASH_MODE, "FlashMode", N_("Flash mode"), ""},
	{MNOTE_FUJI_TAG_FLASH_STRENGTH,
	 "FlashStrength", N_("Flash firing strength compensation"), ""},
	{MNOTE_FUJI_TAG_MACRO, "MacroMode", N_("Macro mode"), ""},
	{MNOTE_FUJI_TAG_FOCUS_MODE, "FocusingMode", N_("Focusing mode"), ""},
	{MNOTE_FUJI_TAG_SLOW_SYNC, "SlowSynchro", N_("Slow synchro mode"), ""},
	{MNOTE_FUJI_TAG_PICTURE_MODE, "PictureMode", N_("Picture mode"), ""},
	{MNOTE_FUJI_TAG_UNKNOWN_1, "Unknown1", N_("Unknown 1"), ""},
	{MNOTE_FUJI_TAG_CONT_TAKING, "ContinuousTaking", N_("Continuous taking"), ""},
	{MNOTE_FUJI_TAG_UNKNOWN_2, "Unknown2", N_("Unknown 2"), ""},
	{MNOTE_FUJI_TAG_BLUR_WARNING, "BlurWarning", N_("Blur warning"), ""},
	{MNOTE_FUJI_TAG_FOCUS_WARNING, "AutoFocusWarning", N_("Auto focus warning"), ""},
	{MNOTE_FUJI_TAG_AUTO_EXPOSURE_WARNING, "AutoExposureWarning", N_("Auto exposure warning"), ""},
	{0, NULL, NULL, NULL}
};

const char *
mnote_fuji_tag_get_name (MNoteTag t)
{
	MNoteFujiTag tag = (MNoteFujiTag) t;

	unsigned int i;

	for (i = 0; table[i].name; i++)
		if (table[i].tag == tag)
			break;

	return (_(table[i].name));
}

const char *
mnote_fuji_tag_get_title (MNoteTag t)
{
	MNoteFujiTag tag = (MNoteFujiTag) t;

	unsigned int i;

	bindtextdomain (GETTEXT_PACKAGE, LIBMNOTE_LOCALEDIR);

	for (i = 0; table[i].title; i++)
		if (table[i].tag == tag)
			break;

	return (_(table[i].title));
}

const char *
mnote_fuji_tag_get_description (MNoteTag t)
{
	MNoteFujiTag tag = (MNoteFujiTag) t;

	unsigned int i;

	bindtextdomain (GETTEXT_PACKAGE, LIBMNOTE_LOCALEDIR);

	for (i = 0; table[i].description; i++)
		if (table[i].tag == tag)
			break;

	return (_(table[i].description));
}
