/* mnote-data.h
 *
 * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details. 
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __MNOTE_CONTENT_H__
#define __MNOTE_CONTENT_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <libexif/exif-byte-order.h>
#include <libmnote/mnote-tag.h>
#include <libmnote/mnote-entry.h>

typedef struct _MNoteData        MNoteData;
typedef struct _MNoteDataPrivate MNoteDataPrivate;

typedef void (* MNoteDataForeachEntryFunc) (MNoteData *, MNoteTag, void *);

typedef struct _MNoteDataMethods MNoteDataMethods;
struct _MNoteDataMethods {
	void    (* free)      (MNoteData *);

	void    (* load_data) (MNoteData *, const unsigned char *, unsigned int);
	void    (* save_data) (MNoteData *, unsigned char **, unsigned int *);

	void            (* set_order) (MNoteData *, ExifByteOrder);
	ExifByteOrder   (* get_order) (MNoteData *);
  
	unsigned int    (* get_count)    (MNoteData *);

	MNoteEntry * (* get_entry)    (MNoteData *, MNoteTag);

	void            (* foreach_entry)(MNoteData *, MNoteDataForeachEntryFunc, void *);

	const char *    (* get_tag_name)        (MNoteTag);
	const char *    (* get_tag_title)       (MNoteTag);
	const char *    (* get_tag_description) (MNoteTag);

	char *          (* get_value)    (MNoteData *, MNoteTag);

	void            (* dump_entry)   (MNoteEntry *, unsigned int);

};

struct _MNoteData {
	MNoteDataMethods methods;
	MNoteDataPrivate *priv;
};

void mnote_data_construct (MNoteData *note);

void mnote_data_ref   (MNoteData *note);
void mnote_data_unref (MNoteData *note);
void mnote_data_free  (MNoteData *note);

const char     *mnote_tag_get_name        (MNoteData *note, MNoteTag tag);
const char     *mnote_tag_get_title       (MNoteData *note, MNoteTag tag);
const char     *mnote_tag_get_description (MNoteData *note, MNoteTag tag);

char *mnote_data_get_value (MNoteData *note, MNoteTag tag);

void mnote_data_dump_entry (MNoteData *note, MNoteTag tag, unsigned int indent);

void mnote_data_dump (MNoteData *note, unsigned int indent);

MNoteData *mnote_data_new_from_data (const unsigned char *data,
					   unsigned int size);

void mnote_data_save_to_data (MNoteData *note,
				 unsigned char **data, unsigned int *size);

void          mnote_data_set_byte_order (MNoteData *note, ExifByteOrder order);
ExifByteOrder mnote_data_get_byte_order (MNoteData *note);

void         mnote_data_foreach_entry (MNoteData *note,
					  MNoteDataForeachEntryFunc func,
					  void *user_data);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __MNOTE_CONTENT_H__ */
